@@ -4,9 +4,10 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION='1.22';
+$VERSION='1.23';
 require Net::SMTP;
 use MIME::Base64;
+use Encode;
 use File::Spec;
 use LWP::MediaTypes;
 use Email::Date::Format qw(email_date);
@@ -221,7 +222,8 @@ sub send
   $mail->{contenttype}=$properties{'-contenttype'} if defined $properties{'-contenttype'};
 
   $mail->{subject}='';
-  $mail->{subject}=$properties{'-subject'} if defined $properties{'-subject'};
+#  $mail->{subject}=$properties{'-subject'} if defined $properties{'-subject'};
+  $mail->{subject}=encode("MIME-Q",$properties{'-subject'}) if defined $properties{'-subject'};
 
   $mail->{body}='';
   $mail->{body}=$properties{'-body'} if defined $properties{'-body'};
